@@ -12,8 +12,11 @@ NanoGen GUI front-ends (:mod:`sknano.apps.nanogen_gui`)
 from __future__ import absolute_import, division, print_function
 __docformat__ = 'restructuredtext en'
 
-from ._ng_model import *
-from ._ng_view import *
-from ._ng_controller import *
+try:
+    from ._ng_model import *
+    from ._ng_view import *
+    from ._ng_controller import *
+except Exception as e:
+    print(e)
 
 __all__ = [s for s in dir() if not s.startswith('_')]
