@@ -22,7 +22,7 @@ __all__ = ['Atom']
 
 
 @total_ordering
-class Atom(object):
+class Atom:
     """Base class for abstract representation of structure atom.
 
     Parameters
@@ -32,25 +32,31 @@ class Atom(object):
         an element atomic number :math:`\\boldsymbol{Z}`.
 
     """
-    _atomattrs = ['symbol', 'Z', 'mass']  # private class var
-
     __hash__ = object.__hash__
 
     def __init__(self, element=None, mass=None, **kwargs):
 
-        # set mass first because the element.setter method may check mass value
         if mass is None and 'm' in kwargs:
             mass = kwargs['m']
+            del kwargs['m']
 
         if mass is None:
             mass = 0
+
+        # set mass first because the element.setter method
+        # may check mass value
         self.mass = mass
 
         self.element = element
 
+        self.strrep = "Atom(element={element!s})"
+
     def __str__(self):
-        """Return nice string representation of `Atom`."""
-        return repr(self)
+        """Return a nice string representation of `Atom`."""
+        try:
+            return self.strrep.format(**self.todict())
+        except KeyError:
+            return repr(self)
 
     def __repr__(self):
         """Return canonical string representation of `Atom`."""
@@ -61,8 +67,8 @@ class Atom(object):
         if self is other:
             return True
         else:
-            for p in self._atomattrs:
-                if getattr(self, p) != getattr(other, p):
+            for attr in self.__dir__():
+                if getattr(self, attr) != getattr(other, attr):
                     return False
             return True
 
@@ -73,6 +79,9 @@ class Atom(object):
     #def __mul__(self, other):
     #    """Multiply atom
 
+    def __dir__(self):
+        return ['element', 'Z', 'mass']
+
     @property
     def Z(self):
         """Atomic number :math:`Z`.
