@@ -34,15 +34,13 @@ class Atoms(UserList):
 
 
     """
-    _atomattrs = ['symbol', 'Z', 'mass']
-
-    def __init__(self, atoms=None, copylist=True, deepcopy=False):
-        super(Atoms, self).__init__(initlist=atoms,
-                                    copylist=copylist,
-                                    deepcopy=deepcopy)
+    def __init__(self, atoms=None, copylist=True, deepcopy=False, **kwargs):
+        super().__init__(initlist=atoms, copylist=copylist, deepcopy=deepcopy)
+        self.kwargs = kwargs
 
     def __str__(self):
-        return repr(self)
+        """Return a nice string representation of `Atoms`."""
+        return '\n'.join([str(atom) for atom in self])
 
     def __repr__(self):
         """Return canonical string representation of `Atoms`."""
@@ -100,7 +98,8 @@ class Atoms(UserList):
         """
         if invert:
             condition = ~condition
-        return self.__class__(atoms=np.asarray(self)[condition].tolist())
+        return self.__class__(atoms=np.asarray(self)[condition].tolist(),
+                              **self.kwargs)
 
     def get_atoms(self, asarray=False):
         """Return list of `Atoms`.
