@@ -38,86 +38,83 @@ class XAtom(Atom):
     x, y, z : float, optional
         :math:`x, y, z` components of `XAtom` position vector relative to
         origin.
-    atomID : int, optional
+    id : int, optional
         atom ID
-    moleculeID : int, optional
+    mol : int, optional
         molecule ID
-    atomtype : int, optional
+    type : int, optional
         atom type
     q : {int, float}, optional
         Net charge of `XAtom`.
     vx, vy, vz : float, optional
         :math:`v_x, v_y, v_z` components of `XAtom` velocity.
-    nx, ny, nz : int, optional
-        :math:`n_x, n_y, n_z` image flags
 
     """
-    _atomattrs = Atom._atomattrs + \
-        ['atomID', 'moleculeID', 'atomtype', 'q', 'dr',
-         'r', 'x', 'y', 'z', 'v', 'vx', 'vy', 'vz',
-         'f', 'fx', 'fy', 'fz', 'n', 'nx', 'ny', 'nz',
-         'pe', 'ke', 'etotal']
-
     __hash__ = Atom.__hash__
 
-    def __init__(self, element=None, atomID=0, moleculeID=0, atomtype=1,
+    def __init__(self, element=None, id=0, mol=0, type=1,
                  q=0., mass=None, x=None, y=None, z=None,
+                 ix=None, iy=None, iz=None,
                  vx=None, vy=None, vz=None, fx=None, fy=None, fz=None,
-                 nx=None, ny=None, nz=None, pe=None, ke=None, etotal=None,
-                 **kwargs):
-        if mass is None and 'm' in kwargs:
-            mass = kwargs['m']
+                 pe=None, ke=None, etotal=None, CN=0, **kwargs):
 
-        super(XAtom, self).__init__(element=element, mass=mass)
+        if 'atomID' in kwargs:
+            id = kwargs['atomID']
+            del kwargs['atomID']
+
+        if 'moleculeID' in kwargs:
+            mol = kwargs['moleculeID']
+            del kwargs['moleculeID']
+
+        if 'atomtype' in kwargs:
+            type = kwargs['atomtype']
+            del kwargs['atomtype']
+
+        super().__init__(element=element, mass=mass, **kwargs)
 
-        self.r = Vector([x, y, z])
-        #self._p0 = Point([x, y, z])
         self.dr = Vector(np.zeros(3), p0=[x, y, z])
+        self.r = Vector([x, y, z])
+        self.v = Vector([vx, vy, vz])
+        self.f = Vector([fx, fy, fz])
+        self.i = Point([ix, iy, iz], dtype=int)
 
-        self._v = Vector([vx, vy, vz])
-        self._f = Vector([fx, fy, fz])
-        self._n = Point([nx, ny, nz], dtype=int)
-
-        self._atomID = int(atomID)
-        self._moleculeID = int(moleculeID)
-        self._atomtype = int(atomtype)
-        self._q = q
+        self.id = id
+        self.mol = mol
+        self.type = type
+        self.q = q
 
         self.pe = pe
         self.ke = ke
         self.etotal = etotal
+        self.CN = CN
 
-    def __str__(self):
-        """Return nice string representation of `XAtom`."""
-        strrep = "Atom(element={element!r}, atomID={atomID!r}, " + \
-            "moleculeID={moleculeID!r}, atomtype={atomtype!r})"
-        parameters = dict(element=self.element, atomID=self.atomID,
-                          moleculeID=self.moleculeID, atomtype=self.atomtype)
-
-        return strrep.format(**parameters)
+        self.strrep = "Atom(element={element!r}, id={id!r}, " + \
+            "mol={mol!r}, type={type!r})"
 
     def __repr__(self):
         """Return canonical string representation of `XAtom`."""
-        reprstr = "Atom(element={element!r}, atomID={atomID!r}, " + \
-            "moleculeID={moleculeID!r}, atomtype={atomtype!r}, " + \
-            "q={q!r}, mass={mass!r}, x={x:.6f}, y={y:.6f}, z={z:.6f}, " \
-            "pe={pe!r}, ke={ke!r}, etotal={etotal!r})"
-        parameters = dict(element=self.element, atomID=self.atomID,
-                          moleculeID=self.moleculeID, atomtype=self.atomtype,
-                          q=self.q, mass=self.mass,
-                          x=self.x, y=self.y, z=self.z,
-                          pe=self.pe, ke=self.ke, etotal=self.etotal)
+        reprstr = "Atom(element={element!r}, id={id!r}, mol={mol!r}, " + \
+            "type={type!r}, q={q!r}, mass={mass!r}, " + \
+            "x={x:.6f}, y={y:.6f}, z={z:.6f}, " + \
+            "pe={pe!r}, ke={ke!r}, etotal={etotal!r}, CN={CN!r})"
 
-        return reprstr.format(**parameters)
+        return reprstr.format(**self.todict())
 
     def __eq__(self, other):
-        return super(XAtom, self).__eq__(other)
+        return super().__eq__(other)
 
     def __lt__(self, other):
-        if self.atomID < other.atomID:
+        if self.id < other.id:
             return True
         else:
-            return super(XAtom, self).__lt__(other)
+            return super().__lt__(other)
+
+    def __dir__(self):
+        attrs = super().__dir__()
+        attrs.extend(['id', 'mol', 'type', 'q', 'dr',
+                      'r', 'x', 'y', 'z', 'v', 'vx', 'vy', 'vz',
+                      'f', 'fx', 'fy', 'fz', 'pe', 'ke', 'etotal', 'CN'])
+        return attrs
 
     @property
     def q(self):
@@ -142,13 +139,13 @@ class XAtom(Atom):
         self._q = value
 
     @property
-    def atomID(self):
-        """:attr:`~XAtom.atomID`."""
-        return self._atomID
+    def id(self):
+        """:attr:`~XAtom.id`."""
+        return self._id
 
-    @atomID.setter
-    def atomID(self, value):
-        """Set atom ID of atom.
+    @id.setter
+    def id(self, value):
+        """Set atom id.
 
         Parameters
         ----------
@@ -158,16 +155,16 @@ class XAtom(Atom):
         """
         if not isinstance(value, numbers.Number):
             raise TypeError('Expected a number')
-        self._atomID = int(value)
+        self._id = int(value)
 
     @property
-    def moleculeID(self):
-        """:attr:`~XAtom.moleculeID`."""
-        return self._moleculeID
+    def mol(self):
+        """:attr:`~XAtom.mol`."""
+        return self._mol
 
-    @moleculeID.setter
-    def moleculeID(self, value):
-        """Set :attr:`~XAtom.moleculeID` attribute.
+    @mol.setter
+    def mol(self, value):
+        """Set :attr:`~XAtom.mol`.
 
         Parameters
         ----------
@@ -177,16 +174,16 @@ class XAtom(Atom):
         """
         if not isinstance(value, numbers.Number):
             raise TypeError('Expected a number')
-        self._moleculeID = int(value)
+        self._mol = int(value)
 
     @property
-    def atomtype(self):
-        """:attr:`~XAtom.atomtype`."""
-        return self._atomtype
+    def type(self):
+        """:attr:`~XAtom.type`."""
+        return self._type
 
-    @atomtype.setter
-    def atomtype(self, value):
-        """Set :attr:`~XAtom.atomtype` attribute.
+    @type.setter
+    def type(self, value):
+        """Set :attr:`~XAtom.type`.
 
         Parameters
         ----------
@@ -196,7 +193,7 @@ class XAtom(Atom):
         """
         if not isinstance(value, numbers.Number):
             raise TypeError('Expected a number')
-        self._atomtype = int(value)
+        self._type = int(value)
 
     @property
     def x(self):
@@ -338,7 +335,7 @@ class XAtom(Atom):
 
         Returns
         -------
-        coords : :class:`python:~collections.OrderedDict` or ndarray
+        coords : :class:`~python:collections.OrderedDict` or ndarray
 
         """
         if asdict:
@@ -346,112 +343,6 @@ class XAtom(Atom):
         else:
             return self.r
 
-    @property
-    def nx(self):
-        """:math:`n_x` image flag.
-
-        Returns
-        -------
-        int
-            :math:`n_x` image flag.
-
-        """
-        return self._n.x
-
-    @nx.setter
-    def nx(self, value):
-        """Set :math:`n_x` image flag.
-
-        Parameters
-        ----------
-        value : float
-            :math:`n_x` image flag.
-
-        """
-        if not isinstance(value, numbers.Number):
-            raise TypeError('Expected a number')
-        self._n.x = int(value)
-
-    @property
-    def ny(self):
-        """:math:`n_y` image flag.
-
-        Returns
-        -------
-        int
-            :math:`n_y` image flag.
-
-        """
-        return self._n.y
-
-    @ny.setter
-    def ny(self, value):
-        """Set :math:`n_y` image flag.
-
-        Parameters
-        ----------
-        value : float
-            :math:`n_y` image flag.
-
-        """
-        if not isinstance(value, numbers.Number):
-            raise TypeError('Expected a number')
-        self._n.y = int(value)
-
-    @property
-    def nz(self):
-        """:math:`n_z` image flag.
-
-        Returns
-        -------
-        int
-            :math:`n_z` image flag.
-
-        """
-        return self._n.z
-
-    @nz.setter
-    def nz(self, value):
-        """Set `XAtom` :math:`n_z` image flag.
-
-        Parameters
-        ----------
-        value : float
-            :math:`n_z` image flag.
-
-        """
-        if not isinstance(value, numbers.Number):
-            raise TypeError('Expected a number')
-        self._n.z = int(value)
-
-    @property
-    def n(self):
-        """:math:`n_x, n_y, n_z` image flags of `XAtom`.
-
-        Returns
-        -------
-        ndarray
-            3-element ndarray of [:math:`n_x`, :math:`n_y`, :math:`n_z`]
-            image flags of `XAtom`.
-
-        """
-        return self._n
-
-    @n.setter
-    def n(self, value):
-        """Set :math:`n_x, n_y, n_z` image flags of `XAtom`.
-
-        Parameters
-        ----------
-        value : array_like
-            3-element ndarray of [:math:`n_x`, :math:`n_y`, :math:`n_z`]
-            image flags of `XAtom`.
-
-        """
-        if not isinstance(value, (list, np.ndarray)):
-            raise TypeError('Expected an array_like object')
-        self._n = Point(value, dtype=int)
-
     @property
     def vx(self):
         """:math:`x` component of `XAtom` velocity vector"""
@@ -679,6 +570,18 @@ class XAtom(Atom):
                 value = 0.0
         self._etotal = value
 
+    @property
+    def CN(self):
+        """Return `XAtom` coordination number."""
+        return self._CN
+
+    @CN.setter
+    def CN(self, value):
+        """Set `XAtom` coordination number."""
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number.')
+        self._CN = int(value)
+
     def rezero(self, epsilon=1.0e-10):
         """Re-zero position vector components.
 
@@ -733,11 +636,89 @@ class XAtom(Atom):
         #self.r += t
 
     def todict(self):
-        return dict(element=self.element, atomID=self.atomID,
-                    moleculeID=self.moleculeID, atomtype=self.atomtype,
-                    q=self.q, mass=self.mass,
-                    x=self.x, y=self.y, z=self.z,
-                    vx=self.vx, vy=self.vy, vz=self.vz,
-                    fx=self.fx, fy=self.fy, fz=self.fz,
-                    nx=self.nx, ny=self.ny, nz=self.nz,
-                    pe=self.pe, ke=self.ke, etotal=self.etotal)
+        return dict(element=self.element, id=self.id, mol=self.mol,
+                    type=self.type, q=self.q, mass=self.mass, x=self.x,
+                    y=self.y, z=self.z, vx=self.vx, vy=self.vy, vz=self.vz,
+                    fx=self.fx, fy=self.fy, fz=self.fz, pe=self.pe, ke=self.ke,
+                    etotal=self.etotal, CN=self.CN)
+
+    @property
+    def atomID(self):
+        return self.id
+
+    @atomID.setter
+    def atomID(self, value):
+        self.id = value
+
+    @property
+    def atomtype(self):
+        return self.type
+
+    @atomtype.setter
+    def atomtype(self, value):
+        self.type = value
+
+    @property
+    def moleculeID(self):
+        return self.mol
+
+    @moleculeID.setter
+    def moleculeID(self, value):
+        self.mol = value
+
+    @property
+    def ix(self):
+        """:math:`i_x` image flag."""
+        return self.i.x
+
+    @ix.setter
+    def ix(self, value):
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number')
+        self.i.x = int(value)
+
+    @property
+    def iy(self):
+        """:math:`i_y` image flag."""
+        return self.i.y
+
+    @iy.setter
+    def iy(self, value):
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number')
+        self.i.y = int(value)
+
+    @property
+    def iz(self):
+        """:math:`i_z` image flag."""
+        return self.i.z
+
+    @iz.setter
+    def iz(self, value):
+        if not isinstance(value, numbers.Number):
+            raise TypeError('Expected a number')
+        self.i.z = value
+
+    @property
+    def i(self):
+        """:math:`i_x, i_y, i_z` image flags
+
+        Returns
+        -------
+        `Point`
+
+        """
+        return self._i
+
+    @i.setter
+    def i(self, value):
+        """Set :math:`i_x, i_y, i_z` image flags.
+
+        Parameters
+        ----------
+        value : array_like
+
+        """
+        if not isinstance(value, (list, np.ndarray)):
+            raise TypeError('Expected an array_like object')
+        self._i = Point(value, dtype=int)
