@@ -27,7 +27,6 @@ except ImportError:
                       'nearest-neighbor queries between atoms.')
 
 from ._extended_atoms import XAtoms
-from ._bond import Bond
 from ._bonds import Bonds
 
 __all__ = ['KDTAtoms']
@@ -50,15 +49,12 @@ class KDTAtoms(XAtoms):
         perform deepcopy of atoms list
 
     """
-    _atomattrs = XAtoms._atomattrs + ['CN', 'NN', 'bonds']
+    def __init__(self, kNN=3, NNrc=2.0, **kwargs):
 
-    def __init__(self, atoms=None, copylist=True, deepcopy=False):
-        super(KDTAtoms, self).__init__(atoms=atoms,
-                                       copylist=copylist,
-                                       deepcopy=deepcopy)
+        super().__init__(**kwargs)
 
-        self._kNN = 3
-        self._NNrc = 2.0
+        self.kNN = kNN
+        self.NNrc = NNrc
 
     @property
     def kNN(self):
@@ -71,7 +67,7 @@ class KDTAtoms(XAtoms):
         the kd-tree."""
         if not isinstance(value, numbers.Number):
             raise TypeError('Expected an integer >= 0')
-        self._kNN = int(value)
+        self._kNN = self.kwargs['kNN'] = int(value)
 
     @property
     def NNrc(self):
@@ -84,7 +80,7 @@ class KDTAtoms(XAtoms):
         """Set the cutoff distance to check for neighest neighbors."""
         if not (isinstance(value, numbers.Number) and value >= 0):
             raise TypeError('Expected a real number greater >= 0')
-        self._NNrc = value
+        self._NNrc = self.kwargs['NNrc'] = value
 
     @property
     def atom_tree(self):
@@ -102,12 +98,6 @@ class KDTAtoms(XAtoms):
         return bonds
         #return np.asarray([atom.bonds for atom in self])
 
-    @property
-    def coordination_numbers(self):
-        """Return array of `KDTAtom` coordination numbers."""
-        #self._update_coordination_numbers()
-        return np.asarray([atom.CN for atom in self])
-
     @property
     def nearest_neighbors(self):
         """Return array of nearest-neighbor atoms for each `KDTAtom`."""
@@ -178,44 +168,22 @@ class KDTAtoms(XAtoms):
         if atom_tree is not None:
             NNi = atom_tree.query_ball_point(pts, r, p=p, eps=eps)
 
-        return self.__class__(atoms=np.asarray(self)[NNi].tolist())
+        return self.__class__(atoms=np.asarray(self)[NNi].tolist(),
+                              **self.kwargs)
 
     def update_attrs(self):
-        """Update each :class:`KDTAtom`\ s attributes.
-
-        This method calls the following methods in order:
-
-        #. :meth:`~KDTAtoms.update_nearest_neighbors`
-
-        #. :meth:`~KDTAtoms.update_coordination_numbers`
-
-        #. :meth:`~KDTAtoms.update_bonds`
-
-        """
+        """Update :class:`KDTAtom`\ s attributes."""
         self.update_nearest_neighbors()
-        self.update_coordination_numbers()
-        self.update_bonds()
-
-    def update_bonds(self):
-        """Update :attr:`KDTAtom.bonds` list."""
-        #self._update_nearest_neighbors()
-        for atom in self:
-            atom.bonds = Bonds()
-            [atom.bonds.append(Bond(atom, nn)) for nn in atom.NN]
-
-    def update_coordination_numbers(self):
-        """Update :attr:`KDTAtom.CN`."""
-        #self._update_nearest_neighbors()
-        [setattr(atom, 'CN', atom.NN.Natoms) for atom in self]
 
     def update_nearest_neighbors(self):
         """Update :attr:`KDTAtom.NN`."""
         try:
             NNd, NNi = self.query_atom_tree(k=self.kNN, rc=self.NNrc)
             for j, atom in enumerate(self):
-                atom.NN = self.__class__()
+                NN = self.__class__(**self.kwargs)
                 for k, d in enumerate(NNd[j]):
-                    if d < self.NNrc:
-                        atom.NN.append(self[NNi[j][k]])
+                    if d <= self.NNrc:
+                        NN.append(self[NNi[j][k]])
+                atom.NN = NN
         except ValueError:
             pass
