@@ -10,9 +10,12 @@ Custom NumPy Vector class (:mod:`sknano.core.math._vector`)
 from __future__ import absolute_import, division, print_function
 __docformat__ = 'restructuredtext en'
 
-import copy
+#import copy
 import numbers
+import warnings
+
 import numpy as np
+np.seterr(all='warn')
 
 from ._point import Point
 from ._transforms import rotate, transformation_matrix
@@ -419,7 +422,9 @@ class Vector(np.ndarray):
     @property
     def unit_vector(self):
         """Unit vector for `Vector`."""
-        return self / self.norm
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore')
+            return self / self.norm
 
     @property
     def magnitude(self):
@@ -475,8 +480,8 @@ class Vector(np.ndarray):
         return self.__array__().dot(other.__array__())
 
     def normalize(self):
-        """Normalize the `Vector`."""
-        self[:] = self / self.length
+        """Normalize the `Vector` to a :attr:`~Vector.unit_vector`."""
+        self[:] = self.unit_vector
 
     def projection(self, v):
         """Compute vector projection onto vector `v`."""
