@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """
 ===========================================
-Preset structure data (:mod:`sknano.data`)
+Structure data files (:mod:`sknano.data`)
 ===========================================
 
 .. currentmodule:: sknano.data
@@ -9,6 +9,8 @@ Preset structure data (:mod:`sknano.data`)
 Contents
 ========
 
+fullerenes
+
 """
 from __future__ import division, print_function, absolute_import
 __docformat__ = 'restructuredtext'
