@@ -29,20 +29,16 @@ from ._base import StructureIO, StructureIOError, StructureFormatSpec, \
 __all__ = ['DUMPData', 'DUMPReader', 'DUMPWriter', 'DUMPIOError',
            'DUMPFormatSpec']
 
-attr_dtypes = {'atomID': int, 'atomtype': int, 'bondID': int, 'bondtype': int,
-               'moleculeID': int, 'q': float, 'ervel': float,
-               'm': float, 'mass': float,
+attr_dtypes = {'id': int, 'type': int, 'mol': int, 'q': float, 'mass': float,
                'x': float, 'y': float, 'z': float,
-               'nx': int, 'ny': int, 'nz': int,
+               'ix': int, 'iy': int, 'iz': int,
                'vx': float, 'vy': float, 'vz': float,
+               'fx': float, 'fy': float, 'fz': float,
                'lx': float, 'ly': float, 'lz': float,
                'wx': float, 'wy': float, 'wz': float,
-               'fx': float, 'fy': float, 'fz': float,
-               'atom_id': int, 'molecule_id': int, 'bond_id': int,
-               'atom1': int, 'atom2': int, 'atom3': int, 'atom4': int,
-               'dihedral_id': int, 'dihedraltype': int,
                'shapex': float, 'shapey': float, 'shapez': float,
-               'quatw': float, 'quati': float, 'quatj': float, 'quatk': float}
+               'quatw': float, 'quati': float, 'quatj': float, 'quatk': float,
+               'atom1': int, 'atom2': int, 'atom3': int, 'atom4': int}
 
 
 class DUMPReader(StructureIO):
@@ -66,13 +62,13 @@ class DUMPReader(StructureIO):
         if len(self.dumpfiles) == 0:
             raise ValueError('No dump file specified.')
 
-        self.read_all()
+        self.read()
 
     @property
     def Nsnaps(self):
         return self.trajectory.Nsnaps
 
-    def read_all(self):
+    def read(self):
         """Read all snapshots from each dump file."""
         for dumpfile in self.dumpfiles:
             with open(dumpfile) as f:
@@ -108,7 +104,7 @@ class DUMPReader(StructureIO):
 
     def read_snapshot(self, f):
         try:
-            snapshot = Snapshot()
+            snapshot = Snapshot(self.trajectory)
             f.readline()
             snapshot.timestep = int(f.readline().strip().split()[0])
             f.readline()
@@ -168,11 +164,6 @@ class DUMPReader(StructureIO):
 
                 self.atomattrs = \
                     sorted(self.dumpattrs, key=self.dumpattrs.__getitem__)
-                if 'id' in self.atomattrs:
-                    self.atomattrs[self.atomattrs.index('id')] = 'atomID'
-
-                if 'type' in self.atomattrs:
-                    self.atomattrs[self.atomattrs.index('type')] = 'atomtype'
 
                 self.attr_dtypes = [attr_dtypes[attr] if attr in attr_dtypes
                                     else float for attr in self.atomattrs]
