@@ -20,11 +20,11 @@ from sknano.core.math import Vector
 from ._compute_funcs import *
 from ._extras import get_Ch_type
 
-__all__ = ['MWNTMixin', 'NanotubeMixin', 'NanotubeBundleMixin',
+__all__ = ['MWNTMixin', 'NanotubeMixin', 'SWNTMixin', 'NanotubeBundleMixin',
            'UnrolledSWNTMixin']
 
 
-class NanotubeMixin(object):
+class SWNTMixin(object):
     """Mixin class for nanotube classes."""
     @property
     def n(self):
@@ -139,6 +139,11 @@ class NanotubeMixin(object):
         """
         return compute_t2(self.n, self.m)
 
+    @property
+    def Ch_vec(self):
+        """SWNT chiral vector."""
+        return (self.n, self.m)
+
     @property
     def Ch(self):
         """SWNT circumference :math:`|\\mathbf{C}_h|` in **\u212b**"""
@@ -169,8 +174,14 @@ class NanotubeMixin(object):
 
     @property
     def chiral_type(self):
+        """`SWNT` chiral type."""
         return get_Ch_type((self.n, self.m))
 
+    @property
+    def Tvec(self):
+        """`SWNT` translation vector."""
+        return (self.t1, self.t2)
+
     @property
     def T(self):
         """Length of nanotube unit cell :math:`|\\mathbf{T}|` in \u212b.
@@ -262,6 +273,24 @@ class NanotubeMixin(object):
         """
         return compute_electronic_type(self.n, self.m)
 
+    @property
+    def Lz(self):
+        """SWNT length :math:`L_z = L_{\\mathrm{tube}}` in **nanometers**."""
+        return self.nz * self.T / 10
+
+    @property
+    def fix_Lz(self):
+        return self._fix_Lz
+
+    @fix_Lz.setter
+    def fix_Lz(self, value):
+        if not isinstance(value, bool):
+            raise TypeError('Expected `True` or `False`')
+        self._fix_Lz = value
+        self._assert_integer_nz = True
+        if self.fix_Lz:
+            self._assert_integer_nz = False
+
     @property
     def Natoms(self):
         """Number of atoms in nanotube.
@@ -281,7 +310,7 @@ class NanotubeMixin(object):
         nanotube unit cell and :math:`n_z` is the number of unit cells.
 
         """
-        return compute_Natoms(self.n, self.m, self.nz)
+        return self.Natoms_per_tube
 
     @property
     def Natoms_per_unit_cell(self):
@@ -297,6 +326,35 @@ class NanotubeMixin(object):
         """
         return compute_Natoms_per_unit_cell(self.n, self.m)
 
+    @property
+    def Natoms_per_tube(self):
+        """Number of atoms in nanotube :math:`N_{\\mathrm{atoms/tube}}`."""
+        return compute_Natoms(self.n, self.m, nz=self.nz)
+
+    @property
+    def Ntubes(self):
+        """Number of nanotubes."""
+        return 1
+
+    @property
+    def linear_mass_density(self):
+        """Linear mass density of nanotube in g/nm."""
+        return compute_linear_mass_density(self.n, self.m, bond=self.bond,
+                                           element1=self.element1,
+                                           element2=self.element2)
+
+    @property
+    def tube_length(self):
+        """Alias for :attr:`SWNT.Lz`"""
+        return self.Lz
+
+    @property
+    def tube_mass(self):
+        """SWNT mass in **grams**."""
+        return compute_tube_mass(self.n, self.m, nz=self.nz,
+                                 element1=self.element1,
+                                 element2=self.element2)
+
     @property
     def unit_cell_mass(self):
         """Unit cell mass in atomic mass units."""
@@ -304,27 +362,9 @@ class NanotubeMixin(object):
                                       element1=self.element1,
                                       element2=self.element2)
 
-    @property
-    def Lz(self):
-        """SWNT length :math:`L_z = L_{\\mathrm{tube}}` in
-        **nanometers**."""
-        return self.nz * self.T
-
-    @property
-    def fix_Lz(self):
-        return self._fix_Lz
-
-    @fix_Lz.setter
-    def fix_Lz(self, value):
-        if not isinstance(value, bool):
-            raise TypeError('Expected `True` or `False`')
-        self._fix_Lz = value
-        self._assert_integer_nz = True
-        if self.fix_Lz:
-            self._assert_integer_nz = False
-
     @property
     def unit_cell_symmetry_params(self):
+        """Tuple of `SWNT` unit cell *symmetry parameters*."""
         psi, tau = compute_symmetry_operation(self.n, self.m, bond=self.bond)
         aCh = compute_chiral_angle(self.n, self.m, rad2deg=False)
         dpsi = self.bond * np.cos(np.pi / 6 - aCh) / self.rt
@@ -332,26 +372,231 @@ class NanotubeMixin(object):
 
         return psi, tau, dpsi, dtau
 
+NanotubeMixin = SWNTMixin
+
 
 class MWNTMixin(object):
     """Mixin class for MWNTs."""
-    pass
+
+    @property
+    def chiral_types(self):
+        """List of chiral types for each `MWNT` shell."""
+        return [swnt.chiral_type for swnt in self.shells]
+
+    @property
+    def chiral_set(self):
+        """Set of all chiral types in `MWNT`."""
+        return set(self.chiral_types)
+
+    @property
+    def dt(self):
+        """`MWNT` shell diameters :math:`d_t=\\frac{|\\mathbf{C}_h|}{\\pi}` \
+        in \u212b."""
+        return self.shells[-1].dt
+
+    @property
+    def rt(self):
+        """`MWNT` shell radii :math:`r_t=\\frac{|\\mathbf{C}_h|}{2\\pi}` \
+        in \u212b."""
+        return self.shells[-1].rt
+
+    @property
+    def Natoms(self):
+        """Number of atoms in nanotube.
+
+        .. versionchanged:: 0.3.0
+
+           **Returns total number of atoms per nanotube.**
+           Use :attr:`~MWNT.Natoms_per_unit_cell` to get the number of
+           atoms per unit cell.
+
+        .. math::
+
+           N_{\\mathrm{atoms}} = 2N\\times n_z =
+           \\frac{4(n^2 + m^2 + nm)}{d_R}\\times n_z
+
+        where :math:`N` is the number of graphene hexagons mapped to the
+        nanotube unit cell and :math:`n_z` is the number of unit cells.
+
+        """
+        return self.Natoms_per_tube
+
+    @property
+    def Natoms_per_tube(self):
+        """Number of atoms in `MWNT`."""
+        return np.asarray([swnt.Natoms for swnt in self.shells]).sum()
+
+    @property
+    def Ntubes(self):
+        """Number of `MWNT`\ s."""
+        return 1
+
+    @property
+    def Nwalls(self):
+        """Number of `MWNT` walls."""
+        return len(self.shells)
+
+    @property
+    def Nshells(self):
+        return self.Nwalls
+
+    @property
+    def tube_mass(self):
+        """MWNT mass in **grams**."""
+        return np.asarray([swnt.tube_mass for swnt in self.shells]).sum()
+
+    def generate_dt_mask(self, dt, max_dt_diff=0.5):
+        """Generate boolean mask array.
+
+        Parameters
+        ----------
+        dt : float
+        max_dt_diff : float, optional
+
+        Returns
+        -------
+        dt_mask : :class:`~numpy:numpy.ndarray`
+
+        """
+        dt_mask = np.abs(self._dt_pool - dt) <= max_dt_diff
+        while not np.any(dt_mask):
+            max_dt_diff += max_dt_diff
+            dt_mask = np.abs(self._dt_pool - dt) <= max_dt_diff
+        return dt_mask
+
+    @property
+    def nz(self):
+        """Number of nanotube unit cells along the :math:`z`-axis."""
+        return [swnt.nz for swnt in self.shells]
+
+    @property
+    def Lz(self):
+        """MWNT length :math:`L_z = L_{\\mathrm{tube}}` in **nanometers**."""
+        return [swnt.Lz for swnt in self.shells]
+
+    @property
+    def T(self):
+        """Length of `MWNT` unit cell :math:`|\\mathbf{T}|` in \u212b."""
+        return [swnt.T for swnt in self.shells]
+
+    @property
+    def wall_diameters(self):
+        """`MWNT` shell diameters :math:`d_t=\\frac{|\\mathbf{C}_h|}{\\pi}` \
+        in \u212b."""
+        return [swnt.dt for swnt in self.shells]
+
+    @property
+    def wall_radii(self):
+        """`MWNT` shell radii :math:`r_t=\\frac{|\\mathbf{C}_h|}{2\\pi}` \
+        in \u212b."""
+        return [swnt.rt for swnt in self.shells]
 
 
 class NanotubeBundleMixin(object):
     """Mixin class for nanotube bundles."""
 
-    def compute_bundle_params(self):
-        """Compute/update nanotube bundle parameters."""
+    @property
+    def nx(self):
+        """Number of nanotubes along the :math:`x`-axis."""
+        return self._nx
+
+    @nx.setter
+    def nx(self, value):
+        """Set :math:`n_x`"""
+        if not (isinstance(value, numbers.Number) or value > 0):
+            raise TypeError('Expected a positive integer.')
+        self._nx = int(value)
+
+    @nx.deleter
+    def nx(self):
+        del self._nx
+
+    @property
+    def ny(self):
+        """Number of nanotubes along the :math:`y`-axis."""
+        return self._ny
+
+    @ny.setter
+    def ny(self, value):
+        """Set :math:`n_y`"""
+        if not (isinstance(value, numbers.Number) or value > 0):
+            raise TypeError('Expected a positive integer.')
+        self._ny = int(value)
+
+    @ny.deleter
+    def ny(self):
+        del self._ny
+
+    @property
+    def Lx(self):
+        return self.nx * (self.dt + self.vdw_spacing) / 10
+
+    @property
+    def Ly(self):
+        return self.ny * (self.dt + self.vdw_spacing) / 10
+
+    @property
+    def bundle_geometry(self):
+        return self._bundle_geometry
+
+    @bundle_geometry.setter
+    def bundle_geometry(self, value):
+        if value is not None and value not in self._bundle_geometries:
+            print('Unrecognized `bundle_geometry`: {!r}'.format(value))
+            value = None
+        self._bundle_geometry = value
+
+    @property
+    def bundle_packing(self):
+        return self._bundle_packing
+
+    @bundle_packing.setter
+    def bundle_packing(self, value):
+        if value is None and \
+                self.bundle_geometry in ('square', 'rectangle'):
+            value = 'ccp'
+        elif value is None and \
+                self.bundle_geometry in ('triangle', 'hexagon'):
+            value = 'hcp'
+
+        if value is not None and value not in ('ccp', 'hcp'):
+            raise ValueError('Expected value to be `hcp` or `ccp`')
+
+        self._bundle_packing = value
+        #self.generate_bundle_coords()
+
+    @bundle_packing.deleter
+    def bundle_packing(self):
+        del self._bundle_packing
+
+    @property
+    def bundle_mass(self):
+        return self.Ntubes * self.tube_mass
+
+    @property
+    def Natoms(self):
+        return self.Natoms_per_bundle
+
+    @property
+    def Natoms_per_tube(self):
+        """Number of atoms in nanotube :math:`N_{\\mathrm{atoms/tube}}`."""
+        return super(NanotubeBundleMixin, self).Natoms_per_tube
+
+    @property
+    def Natoms_per_bundle(self):
+        return self.Ntubes * self.Natoms_per_tube
+
+    @property
+    def Ntubes(self):
+        return len(self.bundle_coords)
+
+    def generate_bundle_coords(self):
+        """Generate coordinates of bundle tubes."""
+        self.r1 = Vector()
+        self.r2 = Vector()
+        self.bundle_coords = []
 
         self.r1.x = self.dt + self.vdw_spacing
-        if self.bundle_packing is None and \
-                self.bundle_geometry in ('square', 'rectangle'):
-            self._bundle_packing = 'ccp'
-        elif self.bundle_packing is None and \
-                self.bundle_geometry in ('triangle', 'hexagon'):
-            self._bundle_packing = 'hcp'
-
         if self.bundle_packing in ('cubic', 'ccp'):
             self.r2.y = self.r1.x
         else:
@@ -404,73 +649,6 @@ class NanotubeBundleMixin(object):
                     dr = nx * self.r1 + ny * self.r2
                     self.bundle_coords.append(dr)
 
-    @property
-    def nx(self):
-        """Number of nanotubes along the :math:`x`-axis."""
-        return self._nx
-
-    @nx.setter
-    def nx(self, value):
-        """Set :math:`n_x`"""
-        if not (isinstance(value, numbers.Number) or value > 0):
-            raise TypeError('Expected a positive integer.')
-        self._nx = int(value)
-
-    @nx.deleter
-    def nx(self):
-        del self._nx
-
-    @property
-    def ny(self):
-        """Number of nanotubes along the :math:`y`-axis."""
-        return self._ny
-
-    @ny.setter
-    def ny(self, value):
-        """Set :math:`n_y`"""
-        if not (isinstance(value, numbers.Number) or value > 0):
-            raise TypeError('Expected a positive integer.')
-        self._ny = int(value)
-
-    @ny.deleter
-    def ny(self):
-        del self._ny
-
-    @property
-    def Lx(self):
-        return self.nx * (self.dt + self.vdw_spacing) / 10
-
-    @property
-    def Ly(self):
-        return self.ny * (self.dt + self.vdw_spacing) / 10
-
-    @property
-    def bundle_packing(self):
-        return self._bundle_packing
-
-    @bundle_packing.setter
-    def bundle_packing(self, value):
-        if value not in ('ccp', 'hcp'):
-            raise ValueError('Expected value to be `hcp` or `ccp`')
-        self._bundle_packing = value
-        self.compute_bundle_params()
-
-    @bundle_packing.deleter
-    def bundle_packing(self):
-        del self._bundle_packing
-
-    @property
-    def bundle_mass(self):
-        return self.Ntubes * self.tube_mass
-
-    @property
-    def Natoms_per_bundle(self):
-        return self.Ntubes * self.Natoms_per_tube
-
-    @property
-    def Ntubes(self):
-        return len(self.bundle_coords)
-
 
 class UnrolledSWNTMixin(object):
     """Mixin class for unrolled nanotubes."""
